==> zio-aws-cloudfront_2.13-5.17.104.12-sources.jar: zio/aws/cloudfront/model/ListResponseHeadersPoliciesRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListResponseHeadersPoliciesRequest(
    `type`: Option[zio.aws.cloudfront.model.ResponseHeadersPolicyType] = None,
    marker: Option[String] = None,
    maxItems: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest = {
    import ListResponseHeadersPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(maxItems.map(value => value: java.lang.String))(
        _.maxItems
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly =
    zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest
      .wrap(buildAwsValue())
}
object ListResponseHeadersPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest =
      zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest(
        `type`.map(value => value),
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def `type`: Option[zio.aws.cloudfront.model.ResponseHeadersPolicyType]
    def marker: Option[String]
    def maxItems: Option[String]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.ResponseHeadersPolicyType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ) extends zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly {
    override val `type`
        : Option[zio.aws.cloudfront.model.ResponseHeadersPolicyType] = scala
      .Option(impl.`type`())
      .map(value =>
        zio.aws.cloudfront.model.ResponseHeadersPolicyType.wrap(value)
      )
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val maxItems: Option[String] =
      scala.Option(impl.maxItems()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ): zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cloudfront_2.13-6.20.56.2-sources.jar: zio/aws/cloudfront/model/ListResponseHeadersPoliciesRequest.scala <==
package zio.aws.cloudfront.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ListResponseHeadersPoliciesRequest(
    `type`: Optional[zio.aws.cloudfront.model.ResponseHeadersPolicyType] =
      Optional.Absent,
    marker: Optional[String] = Optional.Absent,
    maxItems: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest = {
    import ListResponseHeadersPoliciesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(maxItems.map(value => value: java.lang.String))(
        _.maxItems
      )
      .build()
  }
  def asReadOnly
      : zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly =
    zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest
      .wrap(buildAwsValue())
}
object ListResponseHeadersPoliciesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest =
      zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest(
        `type`.map(value => value),
        marker.map(value => value),
        maxItems.map(value => value)
      )
    def `type`: Optional[zio.aws.cloudfront.model.ResponseHeadersPolicyType]
    def marker: Optional[String]
    def maxItems: Optional[String]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.cloudfront.model.ResponseHeadersPolicyType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getMaxItems: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("maxItems", maxItems)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ) extends zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly {
    override val `type`
        : Optional[zio.aws.cloudfront.model.ResponseHeadersPolicyType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value =>
          zio.aws.cloudfront.model.ResponseHeadersPolicyType.wrap(value)
        )
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val maxItems: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.maxItems())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudfront.model.ListResponseHeadersPoliciesRequest
  ): zio.aws.cloudfront.model.ListResponseHeadersPoliciesRequest.ReadOnly =
    new Wrapper(impl)
}
